@@ -19,6 +19,7 @@ from hachoir_parser import createParser, HachoirParserList, ValidateError
 from hachoir_core.compatibility import all
 from locale import setlocale, LC_ALL
 from array import array
+from datetime import datetime
 import random
 import os
 import sys
@@ -162,7 +163,7 @@ def checkJPEG(parser): return (
     checkValue(parser, "app0/content/jfif", "JFIF\x00"),
     checkValue(parser, "app0/content/ver_maj", 1),
     checkValue(parser, "photoshop/content/signature", "Photoshop 3.0"),
-    checkValue(parser, "photoshop/content/copyright_flg/content", "\0\0"),
+    checkValue(parser, "photoshop/content/copyright_flag/content", "\0\0"),
     checkValue(parser, "exif/content/header", "Exif\0\0"),
     checkValue(parser, "exif/content/header2", 42))
 
@@ -209,12 +210,12 @@ def checkCACertClass3(parser): return (
 )
 
 def checkPYC(parser): return (
-    checkValue(parser, "/code/consts/item[0]", 42),
-    checkValue(parser, "/code/stack_size", 4),
-    checkValue(parser, "/code/consts/item[1]", 2535301200456458802993406410752L),
-    checkValue(parser, "/code/consts/item[4]", 0.3j),
-    checkValue(parser, "/code/consts/item[8]", "abc"),
-    checkValue(parser, "/code/filename", "pyc_example.py"))
+    checkValue(parser, "/content/consts/item[0]", 42),
+    checkValue(parser, "/content/stack_size", 4),
+    checkValue(parser, "/content/consts/item[1]", 2535301200456458802993406410752L),
+    checkValue(parser, "/content/consts/item[4]", 0.3j),
+    checkValue(parser, "/content/consts/item[8]", "abc"),
+    checkValue(parser, "/content/filename", "pyc_example.py"))
 
 def checkReferenceMapClass(parser): return (
     checkValue(parser, "/minor_version", 3),
@@ -261,6 +262,7 @@ def checkExt2(parser): return (
     checkValue(parser, "/group_desc/group[0]/free_blocks_count", 44),
     checkValue(parser, "/group[0]/block_bitmap/item[9]", False),
     checkDisplay(parser, "/group[0]/inode_table/inode[1]/file_type", "Directory"),
+    checkDesc(parser, "/group[0]/inode_table/inode[10]", u"Inode 11: file, size=1024 bytes, mode=drwxr-xr-x"),
     checkValue(parser, "/group[0]/inode_table/inode[11]/size", 1816),
     checkDisplay(parser, "/group[0]/inode_table/inode[11]/ctime", u'2006-12-04 23:22:00'),
 )
@@ -335,7 +337,7 @@ def checkCercle(parser): return (
 
 def checkEula(parser): return (
     checkDisplay(parser, "/pe_header/cpu", "Intel 80386"),
-    checkDisplay(parser, "/pe_opt_header/subsystem", "Windows/GUI"),
+    checkDisplay(parser, "/pe_opt_header/subsystem", "Windows GUI"),
     checkDisplay(parser, "/pe_opt_header/import/rva", "0x00008314"),
     checkDisplay(parser, "/section_hdr[1]/mem_size", "4632 bytes"),
     checkValue(parser, "/section_hdr[1]/is_readable", True),
@@ -437,6 +439,22 @@ def checkPTM(parser): return (
     checkValue(parser, "/pattern[0]/row[0]/note[0]/effect", 15),
 )
 
+def checkVimLNK(parser): return (
+    checkValue(parser, "/creation_time", datetime(2006, 5, 7, 14, 18, 32)),
+    checkValue(parser, "/target_filesize", 1363968),
+)
+
+def checkSevenzipCHM(parser): return (
+    checkValue(parser, "/itsf/version", 3),
+    checkDisplay(parser, "/itsf/lang_id", u"Russian"),
+    checkDisplay(parser, "/itsf/dir_uuid/time", u"1997-01-31 20:42:14.890625"),
+    checkDisplay(parser, "/itsf/stream_uuid/variant", u"Microsoft Corporation"),
+    checkDisplay(parser, "/itsf/stream_uuid/mac", u'INTEL CORPORATION - HF1-06 [22:e6:ec]'),
+    checkDisplay(parser, "/file_size/file_size", u"75.6 KB"),
+    checkDisplay(parser, "/dir/itsp/lang_id", u"English United States"),
+    checkValue(parser, "/dir/pmgl[0]/entry[1]/name", u"/#IDXHDR"),
+)
+
 testcase_files = (
     (u"yellowdude.3ds", checkYellowdude),
     (u"logo-kubuntu.png", checkLogoUbuntu),
@@ -486,6 +504,8 @@ testcase_files = (
     (u"dontyou.xm", checkXM),
     (u"satellite_one.s3m", checkS3M),
     (u"anti-arpeggio_tune.ptm", checkPTM),
+    (u"vim.lnk", checkVimLNK),
+    (u"7zip.chm", checkSevenzipCHM),
 )
 
 def checkFile(filename, check_parser):
